@@ -511,7 +511,7 @@ Arnolfini.frontPageColors = function ()
 	{
 		tag = Arnolfini.colorMapping[i];
 		
-		$("body.template-front_page_view .tag_" + tag['tag']).each(function () {
+		$("body.template-front_page_view .tag_" + tag['tag'].replace(" ", "_" )).each(function () {
 			var taken = false;
 			
 			for (c in colors)
