@@ -10,16 +10,9 @@ from Products.CMFCore.utils import getToolByName
 from Products.CMFPlone.PloneBatch import Batch
 from datetime import date
 from DateTime import DateTime
-
-from plone.registry.interfaces import IRegistry
-from plone.app.event.interfaces import IEventSettings
-from plone.event.interfaces import IEventAccessor
-from plone.event.utils import default_timezone as fallback_default_timezone
-
 from plone.app.querystring import queryparser
 from collective.media.interfaces import ICanContainMedia
 from collective.portlet.relateditems.relateditems import Renderer as RelatedItemsRenderer
-from plone.app.event.browser.event_listing import EventListing as AppEventListing
 from plone.portlet.collection.collection import Renderer as CollectionPortletRenderer
 from collective.portlet.manualRelated.manualrelatedportlet import Renderer as ManualRelatedPortletRenderer
 import re
@@ -28,7 +21,6 @@ import json
 from zope.component import getMultiAdapter
 from Acquisition import aq_inner, aq_parent
 from ZTUtils import make_query
-from zope.app.component.hooks import getSite
 
 from plone.i18n.normalizer.interfaces import IIDNormalizer
 from zope.component import queryUtility
@@ -44,7 +36,6 @@ from Products.CMFCore.interfaces import ISiteRoot
 from plone.app.registry.browser.controlpanel import ControlPanelFormWrapper
 from plone.app.registry.browser.controlpanel import RegistryEditForm
 from Products.statusmessages.interfaces import IStatusMessage
-from plone.app.event.recurrence import Occurrence
 
 try:
     from Products.PloneGetPaid.interfaces import IBuyableMarker
@@ -146,26 +137,10 @@ class CommonBrowserView(BrowserView):
             item = brains[0]
         
         for tag in item.Subject:
-            classes.append("tag_%s"%tag)
+            classes.append("tag_%s"%tag.replace(" ", "_"))
         
         return " ".join(classes)
     
-    def getReviewState(self, item):
-        if hasattr(item, 'review_state'):
-            return item.review_state
-        else:
-            catalog = getToolByName(self.context, 'portal_catalog')
-            brains = catalog.queryCatalog({"UID": item.UID()})
-            item = brains[0]
-            return item.review_state
-        
-    def getEventFromOccurence(self, occ):
-        context = occ.context
-        if isinstance(context, Occurrence):
-            return context.getParentNode()
-        else:
-            return occ.context
-    
     def slideshow(self, parent):
         """
         Creates a slideshow with the media from parent
@@ -372,30 +347,16 @@ class CommonBrowserView(BrowserView):
         """
         Formats the start and end dates properly and marks the event as past or future
         """
-        portal_timezone = None
-        reg = queryUtility(IRegistry, context=getSite(), default=None)
-        if reg:
-            portal_timezone= reg.forInterface(
-                    IEventSettings, prefix="plone.app.event").portal_timezone
-            
-        if not portal_timezone:
-            portal_timezone = fallback_default_timezone()
-        
         if event.portal_type != 'Event' and event.portal_type != 'Media Event':
             return ""
         
-        #start = event.start()
-        #end = event.end()
-        start = IEventAccessor(event).start
-        end = IEventAccessor(event).end
-        
-        if start is None or end is None:
-            if start is None and end is None:
+        if event.start() is None or event.end() is None:
+            if event.start() is None and event.end() is None:
                 return ""
             else:
                 samedate = True
         else:
-            samedate = start.strftime('%d - %m - %Y') == end.strftime('%d - %m - %Y')
+            samedate = event.start().strftime('%d - %m - %Y') == event.end().strftime('%d - %m - %Y')
             
         exceptions = ""
         
@@ -404,10 +365,10 @@ class CommonBrowserView(BrowserView):
             
         finalDatesFmt = '<div class="dates %(class)s"><span class="dateText">%(dates)s%(hours)s %(exceptions)s</span></div>'
         
-        dates = "%s"%(samedate and (start is not None and start.strftime('%A %d %B %Y') or end.strftime('%A %d %B %Y')) or "%s to %s"%(start.strftime('%A %d %B %Y'), end.strftime('%A %d %B %Y')))
+        dates = "%s"%(samedate and (event.start() is not None and event.start().strftime('%A %d %B %Y') or event.end().strftime('%A %d %B %Y')) or "%s to %s"%(event.start().strftime('%A %d %B %Y'), event.end().strftime('%A %d %B %Y')))
         
-        openingHour = start is not None and start.strftime('%H:%M') or ""
-        closingHour = end is not None and end.strftime('to %H:%M') or ""
+        openingHour = event.start() is not None and event.start().strftime('%H:%M') or ""
+        closingHour = event.end() is not None and event.end().strftime('to %H:%M') or ""
         hoursExist = 'to %s'%openingHour != closingHour
         
         hours = hoursExist and '<span class="hours">, %s %s</span>'%(openingHour, closingHour) or '<span class="hours">, %s</span>'%openingHour
@@ -717,15 +678,6 @@ class EventListingView(FolderListing):
         else:
             return u''
     
-    
-class AppEventListingView(CommonBrowserView, AppEventListing):
-    """
-    plone.app.event event listing vie for the calendar
-    """
-    
-    
-    
-    
 class SearchView(CommonBrowserView, Search):
     """
     Adding to Search view
@@ -966,4 +918,4 @@ class WeekDayForm(RegistryEditForm):
     """
 
 WeekDayFormView = wrap_form(WeekDayForm)
-    
+    
\ No newline at end of file
